@@ -1,14 +1,16 @@
 # encoding: utf-8
 import datetime
-import os
 from south.db import db
 from south.v2 import SchemaMigration
 from django.db import models
 
-APP_NAME = os.path.basename(os.path.dirname(os.path.dirname(__file__)))
 class Migration(SchemaMigration):
     
     def forwards(self, orm):
+
+        from django_authenticator.util import migration_was_applied
+        if migration_was_applied(__file__, 'django_authopenid'):
+            return
         
         # Adding model 'Nonce'
         db.create_table('django_authopenid_nonce', (
@@ -17,7 +19,7 @@ class Migration(SchemaMigration):
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
             ('server_url', self.gf('django.db.models.fields.CharField')(max_length=255)),
         ))
-        db.send_create_signal(APP_NAME, ['Nonce'])
+        db.send_create_signal('django_authopenid', ['Nonce'])
 
         # Adding model 'Association'
         db.create_table('django_authopenid_association', (
@@ -29,7 +31,7 @@ class Migration(SchemaMigration):
             ('lifetime', self.gf('django.db.models.fields.IntegerField')()),
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
         ))
-        db.send_create_signal(APP_NAME, ['Association'])
+        db.send_create_signal('django_authopenid', ['Association'])
 
         # Adding model 'UserAssociation'
         db.create_table('django_authopenid_userassociation', (
@@ -37,7 +39,7 @@ class Migration(SchemaMigration):
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
             ('openid_url', self.gf('django.db.models.fields.CharField')(max_length=255)),
         ))
-        db.send_create_signal(APP_NAME, ['UserAssociation'])
+        db.send_create_signal('django_authopenid', ['UserAssociation'])
 
         # Adding model 'UserPasswordQueue'
         db.create_table('django_authopenid_userpasswordqueue', (
@@ -46,7 +48,7 @@ class Migration(SchemaMigration):
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
             ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], unique=True)),
         ))
-        db.send_create_signal(APP_NAME, ['UserPasswordQueue'])
+        db.send_create_signal('django_authopenid', ['UserPasswordQueue'])
 
         # Adding model 'ExternalLoginData'
         db.create_table('django_authopenid_externallogindata', (
@@ -55,7 +57,7 @@ class Migration(SchemaMigration):
             ('external_session_data', self.gf('django.db.models.fields.TextField')()),
             ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], null=True)),
         ))
-        db.send_create_signal(APP_NAME, ['ExternalLoginData'])
+        db.send_create_signal('django_authopenid', ['ExternalLoginData'])
     
     
     def backwards(self, orm):
@@ -131,7 +133,7 @@ class Migration(SchemaMigration):
             'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
             'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
         },
-        APP_NAME + '.association': {
+        'django_authopenid.association': {
             'Meta': {'object_name': 'Association'},
             'assoc_type': ('django.db.models.fields.TextField', [], {'max_length': '64'}),
             'handle': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
@@ -141,27 +143,27 @@ class Migration(SchemaMigration):
             'secret': ('django.db.models.fields.TextField', [], {'max_length': '255'}),
             'server_url': ('django.db.models.fields.TextField', [], {'max_length': '2047'})
         },
-        APP_NAME + '.externallogindata': {
+        'django_authopenid.externallogindata': {
             'Meta': {'object_name': 'ExternalLoginData'},
             'external_session_data': ('django.db.models.fields.TextField', [], {}),
             'external_username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '40'}),
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True'})
         },
-        APP_NAME + '.nonce': {
+        'django_authopenid.nonce': {
             'Meta': {'object_name': 'Nonce'},
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'salt': ('django.db.models.fields.CharField', [], {'max_length': '40'}),
             'server_url': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
             'timestamp': ('django.db.models.fields.IntegerField', [], {})
         },
-        APP_NAME + '.userassociation': {
+        'django_authopenid.userassociation': {
             'Meta': {'object_name': 'UserAssociation'},
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'openid_url': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
             'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'unique': 'True'})
         },
-        APP_NAME + '.userpasswordqueue': {
+        'django_authopenid.userpasswordqueue': {
             'Meta': {'object_name': 'UserPasswordQueue'},
             'confirm_key': ('django.db.models.fields.CharField', [], {'max_length': '40'}),
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
@@ -170,4 +172,4 @@ class Migration(SchemaMigration):
         }
     }
     
-    complete_apps = [APP_NAME]
+    complete_apps = ['django_authopenid']
